<?php

namespace fid_bbi\Db\Table;

use  Zend\Db\Sql\Select,
     Zend\Db\Sql\Expression;

trait ResourceTagsTrait
{

    /**
     * Get a subquery used for determining first post date of a tag.
     *
     * @return Select
     */
    protected function getFirstPostedSubquery()
    {
        $sub = new Select('resource_tags');
        $sub->columns(
            [
                'tag_id',
                'first_posted' => new Expression('MIN(?)', ['posted'], [Expression::TYPE_IDENTIFIER])
            ]
        );
        $sub->group(['tag_id']);
        return $sub;
    }

    protected function addFirstPosted($select,$olderThan=true,$age = "7 days",$resourceTagsTableName = 'rt') {

        $select->join(
            ['first' => $this->getFirstPostedSubquery()],
            $resourceTagsTableName.'.tag_id = first.tag_id',
            [],
            Select::JOIN_INNER
        );
        if ($olderThan) {
            $select->where->lessThan(
                'first.first_posted',
                date('Y-m-d H:i:s', strtotime("-" . $age))
            );
        } else {
            // otherwise we look for younger entries
            $select->where->greaterThan(
                'first.first_posted',
                date('Y-m-d H:i:s', strtotime("-" . $age))
            );
        }
    }
}