<?php
/**
 * Factory for view helpers.
 *
 * PHP version 7
 *
 * Copyright (C) Leipzig University Library 2021.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Dorain Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid_bbi\Helper;

use Interop\Container\ContainerInterface;

/**
 * Factory for Root view helpers.
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Dorain Merz <merz@ub.uni-leipzig.de>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
class Factory
{
    /**
     * Construct the Rss helper.
     *
     * @param ContainerInterface $container Service manager.
     *
     * @return Rss
     */
    public static function getRss(ContainerInterface $container)
    {
        return new Rss(
            $container->get('VuFind\Config')->get('config')->RssConsumer,
            $container->get('VuFind\Date\Converter'),
            $container->get('VuFind\Cache\Manager')->getCache('object',Rss::class)
        );
    }
}
