<?php
/**
 * View helper for inserting an SVG icon
 *
 * PHP version 7
 *
 * Copyright (C) Aspectis 2020.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Tobias Schäfer <ts@aspectis.net>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
namespace fid_bbi\View\Helper\Root;

/*
 * View helper for inserting an SVG icon.
 *
 * Included SVG files must be present in <theme directory>/icons and
 * not have a class on the root element, nor an XML declaration.
 *
 * @category VuFind
 * @package  View_Helpers
 * @author   Tobias Schäfer <ts@aspectis.net>
 * @license  http://opensource.org/licenses/gpl-2.0.php GNU General Public License
 * @link     https://vufind.org/wiki/development Wiki
 */
class Icon
{
    /**
     * Construct the SVG icon template helper.
     *
     * @return \Closure which accepts the $name (and optional $class) of an icon
     * and returns an SVG string
     */
    public function __invoke(\Zend\ServiceManager\ServiceManager $serviceManager): \Closure
    {
        $themeInfo = $serviceManager->get('VuFindTheme\ThemeInfo');
        $iconsDir = $themeInfo->getBaseDir() . '/' . $themeInfo->getTheme() . '/icons';

        return function (string $name, string $class = 'icon') use ($iconsDir) {
            $svg = file_get_contents("$iconsDir/$name.svg");
            return implode("<svg class=\"$class\" ", explode('<svg ', $svg, 2));
        };
    }
}
